@@ -6,7 +6,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 use File::Copy;
 use File::Path;
@@ -322,7 +322,7 @@ sub untar_in {
 
     mkd($dir) unless -d $dir;
 
-    my $tar_file_abs = rel2abs($tar_file, dirname($tar_file));
+    my $tar_file_abs = rel2abs($tar_file);
 
     cd($dir);
 
